summaryrefslogtreecommitdiff
path: root/includes/pear/Text/Wiki/Parse/Default/Break.php
diff options
context:
space:
mode:
Diffstat (limited to 'includes/pear/Text/Wiki/Parse/Default/Break.php')
-rwxr-xr-x[-rw-r--r--]includes/pear/Text/Wiki/Parse/Default/Break.php7
1 files changed, 3 insertions, 4 deletions
diff --git a/includes/pear/Text/Wiki/Parse/Default/Break.php b/includes/pear/Text/Wiki/Parse/Default/Break.php
index 1a684f1..5a1b10d 100644..100755
--- a/includes/pear/Text/Wiki/Parse/Default/Break.php
+++ b/includes/pear/Text/Wiki/Parse/Default/Break.php
@@ -12,7 +12,7 @@
*
* @license LGPL
*
-* @version $Id: Break.php 180591 2005-02-23 17:38:29Z pmjones $
+* @version $Id$
*
*/
@@ -20,7 +20,7 @@
*
* Parses for explicit line breaks.
*
* This class implements a Text_Wiki_Parse to mark forced line breaks in the
* source text.
*
* @category Text
@@ -31,7 +31,7 @@
*
*/
-class Text_Wiki_Parse_Break extends Text_Wiki_Parse {
+class Text_Wiki_Parse_Default_Break extends Text_Wiki_Parse {
/**
@@ -69,4 +69,3 @@ class Text_Wiki_Parse_Break extends Text_Wiki_Parse {
}
}
-?> \ No newline at end of file
@@ -20,7 +20,7 @@
* Parses for explicit line breaks.
*
-* This class implements a Text_Wiki_Parse to mark forced line breaks in the
+* This class implements a Text_Wiki_Parse_Default to mark forced line breaks in the
* source text.
*